@@ -35,9 +35,11 @@ Counter with CBC-MAC (CCM) mode.
 __all__ = ['CcmMode']
 
 import struct
+from binascii import unhexlify
 
-from Crypto.Util.py3compat import (byte_string, bord, unhexlify,
-                                   _copy_bytes, _is_mutable)
+from Crypto.Util.py3compat import (byte_string, bord,
+                                   _copy_bytes)
+from Crypto.Util._raw_api import is_writeable_buffer
 
 from Crypto.Util.strxor import strxor
 from Crypto.Util.number import long_to_bytes
@@ -52,6 +54,10 @@ def enum(**enums):
 MacStatus = enum(NOT_STARTED=0, PROCESSING_AUTH_DATA=1, PROCESSING_PLAINTEXT=2)
 
 
+class CCMMessageTooLongError(ValueError):
+    pass
+
+
 class CcmMode(object):
     """Counter with CBC-MAC (CCM).
 
@@ -139,10 +145,15 @@ class CcmMode(object):
                              " and in the range 4..16 (not %d)" % mac_len)
 
         # Nonce value
-        if not (nonce and 7 <= len(nonce) <= 13):
+        if not (7 <= len(nonce) <= 13):
             raise ValueError("Length of parameter 'nonce' must be"
                              " in the range 7..13 bytes")
 
+        # Message length (if known already)
+        q = 15 - len(nonce)  # length of Q, the encoded message length
+        if msg_len and len(long_to_bytes(msg_len)) > q:
+            raise CCMMessageTooLongError("Message too long for a %u-byte nonce" % len(nonce))
+
         # Create MAC object (the tag will be the last block
         # bytes worth of ciphertext)
         self._mac = self._factory.new(key,
@@ -153,8 +164,8 @@ class CcmMode(object):
         self._t = None
 
         # Allowed transitions after initialization
-        self._next = [self.update, self.encrypt, self.decrypt,
-                      self.digest, self.verify]
+        self._next = ["update", "encrypt", "decrypt",
+                      "digest", "verify"]
 
         # Cumulative lengths
         self._cumul_assoc_len = 0
@@ -166,7 +177,6 @@ class CcmMode(object):
         self._cache = []
 
         # Start CTR cipher, by formatting the counter (A.3)
-        q = 15 - len(nonce)  # length of Q, the encoded message length
         self._cipher = self._factory.new(key,
                                          self._factory.MODE_CTR,
                                          nonce=struct.pack("B", q - 1) + self.nonce,
@@ -186,9 +196,10 @@ class CcmMode(object):
         assert(isinstance(self._cache, list))
 
         # Formatting control information and nonce (A.2.1)
-        q = 15 - len(self.nonce)  # length of Q, the encoded message length
-        flags = (64 * (self._assoc_len > 0) + 8 * ((self._mac_len - 2) // 2) +
-                 (q - 1))
+        q = 15 - len(self.nonce)  # length of Q, the encoded message length (2..8)
+        flags = (self._assoc_len > 0) << 6
+        flags |= ((self._mac_len - 2) // 2) << 3
+        flags |= q - 1
         b_0 = struct.pack("B", flags) + self.nonce + long_to_bytes(self._msg_len, q)
 
         # Formatting associated data (A.2.2)
@@ -250,12 +261,12 @@ class CcmMode(object):
             A piece of associated data. There are no restrictions on its size.
         """
 
-        if self.update not in self._next:
+        if "update" not in self._next:
             raise TypeError("update() can only be called"
                             " immediately after initialization")
 
-        self._next = [self.update, self.encrypt, self.decrypt,
-                      self.digest, self.verify]
+        self._next = ["update", "encrypt", "decrypt",
+                      "digest", "verify"]
 
         self._cumul_assoc_len += len(assoc_data)
         if self._assoc_len is not None and \
@@ -272,7 +283,7 @@ class CcmMode(object):
         # If MAC has not started yet, we just park the data into a list.
         # If the data is mutable, we create a copy and store that instead.
         if self._mac_status == MacStatus.NOT_STARTED:
-            if _is_mutable(assoc_data_pt):
+            if is_writeable_buffer(assoc_data_pt):
                 assoc_data_pt = _copy_bytes(None, None, assoc_data_pt)
             self._cache.append(assoc_data_pt)
             return
@@ -297,7 +308,7 @@ class CcmMode(object):
         if update_len > 0:
             self._t = self._mac.encrypt(assoc_data_pt[:update_len])[-16:]
 
-    def encrypt(self, plaintext):
+    def encrypt(self, plaintext, output=None):
         """Encrypt data with the key set at initialization.
 
         A cipher object is stateful: once you have encrypted a message
@@ -325,15 +336,19 @@ class CcmMode(object):
           plaintext : bytes/bytearray/memoryview
             The piece of data to encrypt.
             It can be of any length.
+        :Keywords:
+          output : bytearray/memoryview
+            The location where the ciphertext must be written to.
+            If ``None``, the ciphertext is returned.
         :Return:
-            the encrypted data, as a byte string.
-            It is as long as *plaintext*.
+          If ``output`` is ``None``, the ciphertext as ``bytes``.
+          Otherwise, ``None``.
         """
 
-        if self.encrypt not in self._next:
+        if "encrypt" not in self._next:
             raise TypeError("encrypt() can only be called after"
                             " initialization or an update()")
-        self._next = [self.encrypt, self.digest]
+        self._next = ["encrypt", "digest"]
 
         # No more associated data allowed from now
         if self._assoc_len is None:
@@ -348,9 +363,13 @@ class CcmMode(object):
         # Only once piece of plaintext accepted if message length was
         # not declared in advance
         if self._msg_len is None:
+            q = 15 - len(self.nonce)
+            if len(long_to_bytes(len(plaintext))) > q:
+                raise CCMMessageTooLongError("Message too long for a %u-byte nonce" % len(self.nonce))
+
             self._msg_len = len(plaintext)
             self._start_mac()
-            self._next = [self.digest]
+            self._next = ["digest"]
 
         self._cumul_msg_len += len(plaintext)
         if self._cumul_msg_len > self._msg_len:
@@ -364,9 +383,9 @@ class CcmMode(object):
             self._mac_status = MacStatus.PROCESSING_PLAINTEXT
 
         self._update(plaintext)
-        return self._cipher.encrypt(plaintext)
+        return self._cipher.encrypt(plaintext, output=output)
 
-    def decrypt(self, ciphertext):
+    def decrypt(self, ciphertext, output=None):
         """Decrypt data with the key set at initialization.
 
         A cipher object is stateful: once you have decrypted a message
@@ -394,14 +413,19 @@ class CcmMode(object):
           ciphertext : bytes/bytearray/memoryview
             The piece of data to decrypt.
             It can be of any length.
-
-        :Return: the decrypted data (byte string).
+        :Keywords:
+          output : bytearray/memoryview
+            The location where the plaintext must be written to.
+            If ``None``, the plaintext is returned.
+        :Return:
+          If ``output`` is ``None``, the plaintext as ``bytes``.
+          Otherwise, ``None``.
         """
 
-        if self.decrypt not in self._next:
+        if "decrypt" not in self._next:
             raise TypeError("decrypt() can only be called"
                             " after initialization or an update()")
-        self._next = [self.decrypt, self.verify]
+        self._next = ["decrypt", "verify"]
 
         # No more associated data allowed from now
         if self._assoc_len is None:
@@ -416,9 +440,13 @@ class CcmMode(object):
         # Only once piece of ciphertext accepted if message length was
         # not declared in advance
         if self._msg_len is None:
+            q = 15 - len(self.nonce)
+            if len(long_to_bytes(len(ciphertext))) > q:
+                raise CCMMessageTooLongError("Message too long for a %u-byte nonce" % len(self.nonce))
+
             self._msg_len = len(ciphertext)
             self._start_mac()
-            self._next = [self.verify]
+            self._next = ["verify"]
 
         self._cumul_msg_len += len(ciphertext)
         if self._cumul_msg_len > self._msg_len:
@@ -432,8 +460,11 @@ class CcmMode(object):
             self._mac_status = MacStatus.PROCESSING_PLAINTEXT
 
         # Encrypt is equivalent to decrypt with the CTR mode
-        plaintext = self._cipher.encrypt(ciphertext)
-        self._update(plaintext)
+        plaintext = self._cipher.encrypt(ciphertext, output=output)
+        if output is None:
+            self._update(plaintext)
+        else:
+            self._update(output)
         return plaintext
 
     def digest(self):
@@ -447,10 +478,10 @@ class CcmMode(object):
         :Return: the MAC, as a byte string.
         """
 
-        if self.digest not in self._next:
+        if "digest" not in self._next:
             raise TypeError("digest() cannot be called when decrypting"
                             " or validating a message")
-        self._next = [self.digest]
+        self._next = ["digest"]
         return self._digest()
 
     def _digest(self):
@@ -509,10 +540,10 @@ class CcmMode(object):
             or the key is incorrect.
         """
 
-        if self.verify not in self._next:
+        if "verify" not in self._next:
             raise TypeError("verify() cannot be called"
                             " when encrypting a message")
-        self._next = [self.verify]
+        self._next = ["verify"]
 
         self._digest()
         secret = get_random_bytes(16)
@@ -538,22 +569,29 @@ class CcmMode(object):
 
         self.verify(unhexlify(hex_mac_tag))
 
-    def encrypt_and_digest(self, plaintext):
+    def encrypt_and_digest(self, plaintext, output=None):
         """Perform encrypt() and digest() in one step.
 
         :Parameters:
           plaintext : bytes/bytearray/memoryview
             The piece of data to encrypt.
+        :Keywords:
+          output : bytearray/memoryview
+            The location where the ciphertext must be written to.
+            If ``None``, the ciphertext is returned.
         :Return:
-            a tuple with two byte strings:
+            a tuple with two items:
 
-            - the encrypted data
-            - the MAC
+            - the ciphertext, as ``bytes``
+            - the MAC tag, as ``bytes``
+
+            The first item becomes ``None`` when the ``output`` parameter
+            specified a location for the result.
         """
 
-        return self.encrypt(plaintext), self.digest()
+        return self.encrypt(plaintext, output=output), self.digest()
 
-    def decrypt_and_verify(self, ciphertext, received_mac_tag):
+    def decrypt_and_verify(self, ciphertext, received_mac_tag, output=None):
         """Perform decrypt() and verify() in one step.
 
         :Parameters:
@@ -561,14 +599,18 @@ class CcmMode(object):
             The piece of data to decrypt.
           received_mac_tag : bytes/bytearray/memoryview
             This is the *binary* MAC, as received from the sender.
-
-        :Return: the decrypted data (byte string).
+        :Keywords:
+          output : bytearray/memoryview
+            The location where the plaintext must be written to.
+            If ``None``, the plaintext is returned.
+        :Return: the plaintext as ``bytes`` or ``None`` when the ``output``
+            parameter specified a location for the result.
         :Raises ValueError:
             if the MAC does not match. The message has been tampered with
             or the key is incorrect.
         """
 
-        plaintext = self.decrypt(ciphertext)
+        plaintext = self.decrypt(ciphertext, output=output)
         self.verify(received_mac_tag)
         return plaintext
 
