@@ -28,18 +28,20 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ===================================================================
 
-import json
 import unittest
 from binascii import unhexlify
 
 from Crypto.SelfTest.st_common import list_test_cases
-from Crypto.Util.py3compat import tobytes, bchr, _memoryview
+from Crypto.SelfTest.loader import load_test_vectors_wycheproof
+from Crypto.Util.py3compat import tobytes, bchr
 from Crypto.Cipher import AES
 from Crypto.Hash import SHAKE128
 
-from Crypto.Util._file_system import pycryptodome_filename
 from Crypto.Util.strxor import strxor
 
+from Crypto.Cipher._mode_ccm import CCMMessageTooLongError
+
+
 def get_tag_random(tag, length):
     return SHAKE128.new(data=tobytes(tag)).read(length)
 
@@ -48,7 +50,7 @@ class CcmTests(unittest.TestCase):
 
     key_128 = get_tag_random("key_128", 16)
     nonce_96 = get_tag_random("nonce_128", 12)
-    data_128 = get_tag_random("data_128", 16)
+    data = get_tag_random("data", 128)
 
     def test_loopback_128(self):
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
@@ -69,10 +71,10 @@ class CcmTests(unittest.TestCase):
         self.assertNotEqual(nonce1, nonce2)
 
         cipher = AES.new(self.key_128, AES.MODE_CCM, self.nonce_96)
-        ct = cipher.encrypt(self.data_128)
+        ct = cipher.encrypt(self.data)
 
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        self.assertEquals(ct, cipher.encrypt(self.data_128))
+        self.assertEqual(ct, cipher.encrypt(self.data))
 
     def test_nonce_must_be_bytes(self):
         self.assertRaises(TypeError, AES.new, self.key_128, AES.MODE_CCM,
@@ -145,18 +147,18 @@ class CcmTests(unittest.TestCase):
         for mac_len in range(4, 16 + 1, 2):
             cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
                              mac_len=mac_len)
-            _, mac = cipher.encrypt_and_digest(self.data_128)
+            _, mac = cipher.encrypt_and_digest(self.data)
             self.assertEqual(len(mac), mac_len)
 
         # Default MAC length
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        _, mac = cipher.encrypt_and_digest(self.data_128)
+        _, mac = cipher.encrypt_and_digest(self.data)
         self.assertEqual(len(mac), 16)
 
     def test_invalid_mac(self):
         from Crypto.Util.strxor import strxor_c
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        ct, mac = cipher.encrypt_and_digest(self.data_128)
+        ct, mac = cipher.encrypt_and_digest(self.data)
 
         invalid_mac = strxor_c(mac, 0x01)
 
@@ -181,58 +183,64 @@ class CcmTests(unittest.TestCase):
         # Too large
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
                          assoc_len=15)
-        self.assertRaises(ValueError, cipher.update, self.data_128)
+        self.assertRaises(ValueError, cipher.update, self.data)
 
     def test_shorter_assoc_data_than_expected(self):
+        DATA_LEN = len(self.data)
+
         # With plaintext
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         assoc_len=17)
-        cipher.update(self.data_128)
-        self.assertRaises(ValueError, cipher.encrypt, self.data_128)
+                         assoc_len=DATA_LEN + 1)
+        cipher.update(self.data)
+        self.assertRaises(ValueError, cipher.encrypt, self.data)
 
         # With empty plaintext
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         assoc_len=17)
-        cipher.update(self.data_128)
+                         assoc_len=DATA_LEN + 1)
+        cipher.update(self.data)
         self.assertRaises(ValueError, cipher.digest)
 
         # With ciphertext
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         assoc_len=17)
-        cipher.update(self.data_128)
-        self.assertRaises(ValueError, cipher.decrypt, self.data_128)
+                         assoc_len=DATA_LEN + 1)
+        cipher.update(self.data)
+        self.assertRaises(ValueError, cipher.decrypt, self.data)
 
         # With empty ciphertext
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        cipher.update(self.data_128)
+        cipher.update(self.data)
         mac = cipher.digest()
 
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         assoc_len=17)
-        cipher.update(self.data_128)
+                         assoc_len=DATA_LEN + 1)
+        cipher.update(self.data)
         self.assertRaises(ValueError, cipher.verify, mac)
 
     def test_shorter_and_longer_plaintext_than_declared(self):
+        DATA_LEN = len(self.data)
+
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         msg_len=17)
-        cipher.encrypt(self.data_128)
+                         msg_len=DATA_LEN + 1)
+        cipher.encrypt(self.data)
         self.assertRaises(ValueError, cipher.digest)
 
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         msg_len=15)
-        self.assertRaises(ValueError, cipher.encrypt, self.data_128)
+                         msg_len=DATA_LEN - 1)
+        self.assertRaises(ValueError, cipher.encrypt, self.data)
 
     def test_shorter_ciphertext_than_declared(self):
+        DATA_LEN = len(self.data)
+
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        ct, mac = cipher.encrypt_and_digest(self.data_128)
+        ct, mac = cipher.encrypt_and_digest(self.data)
 
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         msg_len=17)
+                         msg_len=DATA_LEN + 1)
         cipher.decrypt(ct)
         self.assertRaises(ValueError, cipher.verify, mac)
 
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96,
-                         msg_len=15)
+                         msg_len=DATA_LEN - 1)
         self.assertRaises(ValueError, cipher.decrypt, ct)
 
     def test_message_chunks(self):
@@ -276,21 +284,21 @@ class CcmTests(unittest.TestCase):
             for chunk in break_up(plaintext, chunk_length):
                 ct2 += cipher.encrypt(chunk)
             self.assertEqual(ciphertext, ct2)
-            self.assertEquals(cipher.digest(), ref_mac)
+            self.assertEqual(cipher.digest(), ref_mac)
 
     def test_bytearray(self):
 
         # Encrypt
         key_ba = bytearray(self.key_128)
         nonce_ba = bytearray(self.nonce_96)
-        header_ba = bytearray(self.data_128)
-        data_ba = bytearray(self.data_128)
+        header_ba = bytearray(self.data)
+        data_ba = bytearray(self.data)
 
         cipher1 = AES.new(self.key_128,
                           AES.MODE_CCM,
                           nonce=self.nonce_96)
-        cipher1.update(self.data_128)
-        ct = cipher1.encrypt(self.data_128)
+        cipher1.update(self.data)
+        ct = cipher1.encrypt(self.data)
         tag = cipher1.digest()
 
         cipher2 = AES.new(key_ba,
@@ -311,7 +319,7 @@ class CcmTests(unittest.TestCase):
         # Decrypt
         key_ba = bytearray(self.key_128)
         nonce_ba = bytearray(self.nonce_96)
-        header_ba = bytearray(self.data_128)
+        header_ba = bytearray(self.data)
         del data_ba
 
         cipher4 = AES.new(key_ba,
@@ -323,21 +331,21 @@ class CcmTests(unittest.TestCase):
         header_ba[:3] = b"\xFF\xFF\xFF"
         pt_test = cipher4.decrypt_and_verify(bytearray(ct_test), bytearray(tag_test))
 
-        self.assertEqual(self.data_128, pt_test)
+        self.assertEqual(self.data, pt_test)
 
     def test_memoryview(self):
 
         # Encrypt
         key_mv = memoryview(bytearray(self.key_128))
         nonce_mv = memoryview(bytearray(self.nonce_96))
-        header_mv = memoryview(bytearray(self.data_128))
-        data_mv = memoryview(bytearray(self.data_128))
+        header_mv = memoryview(bytearray(self.data))
+        data_mv = memoryview(bytearray(self.data))
 
         cipher1 = AES.new(self.key_128,
                           AES.MODE_CCM,
                           nonce=self.nonce_96)
-        cipher1.update(self.data_128)
-        ct = cipher1.encrypt(self.data_128)
+        cipher1.update(self.data)
+        ct = cipher1.encrypt(self.data)
         tag = cipher1.digest()
 
         cipher2 = AES.new(key_mv,
@@ -358,7 +366,7 @@ class CcmTests(unittest.TestCase):
         # Decrypt
         key_mv = memoryview(bytearray(self.key_128))
         nonce_mv = memoryview(bytearray(self.nonce_96))
-        header_mv = memoryview(bytearray(self.data_128))
+        header_mv = memoryview(bytearray(self.data))
         del data_mv
 
         cipher4 = AES.new(key_mv,
@@ -370,48 +378,48 @@ class CcmTests(unittest.TestCase):
         header_mv[:3] = b"\xFF\xFF\xFF"
         pt_test = cipher4.decrypt_and_verify(memoryview(ct_test), memoryview(tag_test))
 
-        self.assertEqual(self.data_128, pt_test)
-    
+        self.assertEqual(self.data, pt_test)
+
     def test_output_param(self):
 
-        pt = b'5' * 16
+        pt = b'5' * 128
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         ct = cipher.encrypt(pt)
         tag = cipher.digest()
 
-        output = bytearray(16)
+        output = bytearray(128)
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         res = cipher.encrypt(pt, output=output)
         self.assertEqual(ct, output)
         self.assertEqual(res, None)
-        
+
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         res = cipher.decrypt(ct, output=output)
         self.assertEqual(pt, output)
         self.assertEqual(res, None)
-        
+
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         res, tag_out = cipher.encrypt_and_digest(pt, output=output)
         self.assertEqual(ct, output)
         self.assertEqual(res, None)
         self.assertEqual(tag, tag_out)
-        
+
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         res = cipher.decrypt_and_verify(ct, tag, output=output)
         self.assertEqual(pt, output)
         self.assertEqual(res, None)
 
     def test_output_param_memoryview(self):
-        
-        pt = b'5' * 16
+
+        pt = b'5' * 128
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         ct = cipher.encrypt(pt)
 
-        output = memoryview(bytearray(16))
+        output = memoryview(bytearray(128))
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         cipher.encrypt(pt, output=output)
         self.assertEqual(ct, output)
-        
+
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         cipher.decrypt(ct, output=output)
         self.assertEqual(pt, output)
@@ -424,7 +432,7 @@ class CcmTests(unittest.TestCase):
 
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         self.assertRaises(TypeError, cipher.encrypt, pt, output=b'0'*16)
-        
+
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         self.assertRaises(TypeError, cipher.decrypt, ct, output=b'0'*16)
 
@@ -434,29 +442,55 @@ class CcmTests(unittest.TestCase):
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
         self.assertRaises(ValueError, cipher.decrypt, ct, output=shorter_output)
 
+    def test_message_too_long(self):
 
-    import sys
-    if sys.version[:3] == "2.6":
-        del test_memoryview
-        del test_output_param_memoryview
+        nonce = b'N' * 13
+        self.assertRaises(CCMMessageTooLongError,
+                          AES.new,
+                          self.key_128,
+                          AES.MODE_CCM,
+                          nonce=nonce,
+                          assoc_len=20,
+                          msg_len=0x10000)
+
+        nonce = b'N' * 7
+        self.assertRaises(CCMMessageTooLongError,
+                          AES.new,
+                          self.key_128,
+                          AES.MODE_CCM,
+                          nonce=nonce,
+                          assoc_len=20,
+                          msg_len=2**64)
+
+        nonce = b'N' * 13
+        cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=nonce)
+        self.assertRaises(CCMMessageTooLongError,
+                          cipher.encrypt,
+                          b'C' * 0x10000)
+
+        nonce = b'N' * 13
+        cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=nonce)
+        self.assertRaises(CCMMessageTooLongError,
+                          cipher.decrypt,
+                          b'C' * 0x10000)
 
 
 class CcmFSMTests(unittest.TestCase):
 
     key_128 = get_tag_random("key_128", 16)
     nonce_96 = get_tag_random("nonce_128", 12)
-    data_128 = get_tag_random("data_128", 16)
+    data = get_tag_random("data", 16)
 
     def test_valid_init_encrypt_decrypt_digest_verify(self):
         # No authenticated data, fixed plaintext
         for assoc_len in (None, 0):
-            for msg_len in (None, len(self.data_128)):
+            for msg_len in (None, len(self.data)):
                 # Verify path INIT->ENCRYPT->DIGEST
                 cipher = AES.new(self.key_128, AES.MODE_CCM,
                                  nonce=self.nonce_96,
                                  assoc_len=assoc_len,
                                  msg_len=msg_len)
-                ct = cipher.encrypt(self.data_128)
+                ct = cipher.encrypt(self.data)
                 mac = cipher.digest()
 
                 # Verify path INIT->DECRYPT->VERIFY
@@ -469,14 +503,14 @@ class CcmFSMTests(unittest.TestCase):
 
     def test_valid_init_update_digest_verify(self):
         # No plaintext, fixed authenticated data
-        for assoc_len in (None, len(self.data_128)):
+        for assoc_len in (None, len(self.data)):
             for msg_len in (None, 0):
                 # Verify path INIT->UPDATE->DIGEST
                 cipher = AES.new(self.key_128, AES.MODE_CCM,
                                  nonce=self.nonce_96,
                                  assoc_len=assoc_len,
                                  msg_len=msg_len)
-                cipher.update(self.data_128)
+                cipher.update(self.data)
                 mac = cipher.digest()
 
                 # Verify path INIT->UPDATE->VERIFY
@@ -484,20 +518,20 @@ class CcmFSMTests(unittest.TestCase):
                                  nonce=self.nonce_96,
                                  assoc_len=assoc_len,
                                  msg_len=msg_len)
-                cipher.update(self.data_128)
+                cipher.update(self.data)
                 cipher.verify(mac)
 
     def test_valid_full_path(self):
         # Fixed authenticated data, fixed plaintext
-        for assoc_len in (None, len(self.data_128)):
-            for msg_len in (None, len(self.data_128)):
+        for assoc_len in (None, len(self.data)):
+            for msg_len in (None, len(self.data)):
                 # Verify path INIT->UPDATE->ENCRYPT->DIGEST
                 cipher = AES.new(self.key_128, AES.MODE_CCM,
                                  nonce=self.nonce_96,
                                  assoc_len=assoc_len,
                                  msg_len=msg_len)
-                cipher.update(self.data_128)
-                ct = cipher.encrypt(self.data_128)
+                cipher.update(self.data)
+                ct = cipher.encrypt(self.data)
                 mac = cipher.digest()
 
                 # Verify path INIT->UPDATE->DECRYPT->VERIFY
@@ -505,7 +539,7 @@ class CcmFSMTests(unittest.TestCase):
                                  nonce=self.nonce_96,
                                  assoc_len=assoc_len,
                                  msg_len=msg_len)
-                cipher.update(self.data_128)
+                cipher.update(self.data)
                 cipher.decrypt(ct)
                 cipher.verify(mac)
 
@@ -525,8 +559,8 @@ class CcmFSMTests(unittest.TestCase):
     def test_valid_multiple_encrypt_or_decrypt(self):
         # Only possible if msg_len is declared in advance
         for method_name in "encrypt", "decrypt":
-            for auth_data in (None, b"333", self.data_128,
-                              self.data_128 + b"3"):
+            for auth_data in (None, b"333", self.data,
+                              self.data + b"3"):
                 if auth_data is None:
                     assoc_len = None
                 else:
@@ -538,36 +572,36 @@ class CcmFSMTests(unittest.TestCase):
                 if auth_data is not None:
                     cipher.update(auth_data)
                 method = getattr(cipher, method_name)
-                method(self.data_128)
-                method(self.data_128)
-                method(self.data_128)
-                method(self.data_128)
+                method(self.data)
+                method(self.data)
+                method(self.data)
+                method(self.data)
 
     def test_valid_multiple_digest_or_verify(self):
         # Multiple calls to digest
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        cipher.update(self.data_128)
+        cipher.update(self.data)
         first_mac = cipher.digest()
         for x in range(4):
             self.assertEqual(first_mac, cipher.digest())
 
         # Multiple calls to verify
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        cipher.update(self.data_128)
+        cipher.update(self.data)
         for x in range(5):
             cipher.verify(first_mac)
 
     def test_valid_encrypt_and_digest_decrypt_and_verify(self):
         # encrypt_and_digest
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        cipher.update(self.data_128)
-        ct, mac = cipher.encrypt_and_digest(self.data_128)
+        cipher.update(self.data)
+        ct, mac = cipher.encrypt_and_digest(self.data)
 
         # decrypt_and_verify
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        cipher.update(self.data_128)
+        cipher.update(self.data)
         pt = cipher.decrypt_and_verify(ct, mac)
-        self.assertEqual(self.data_128, pt)
+        self.assertEqual(self.data, pt)
 
     def test_invalid_multiple_encrypt_decrypt_without_msg_len(self):
         # Once per method, with or without assoc. data
@@ -576,10 +610,10 @@ class CcmFSMTests(unittest.TestCase):
                 cipher = AES.new(self.key_128, AES.MODE_CCM,
                                  nonce=self.nonce_96)
                 if assoc_data_present:
-                    cipher.update(self.data_128)
+                    cipher.update(self.data)
                 method = getattr(cipher, method_name)
-                method(self.data_128)
-                self.assertRaises(TypeError, method, self.data_128)
+                method(self.data)
+                self.assertRaises(TypeError, method, self.data)
 
     def test_invalid_mixing_encrypt_decrypt(self):
         # Once per method, with or without assoc. data
@@ -590,25 +624,25 @@ class CcmFSMTests(unittest.TestCase):
                                  nonce=self.nonce_96,
                                  msg_len=32)
                 if assoc_data_present:
-                    cipher.update(self.data_128)
-                getattr(cipher, method1_name)(self.data_128)
+                    cipher.update(self.data)
+                getattr(cipher, method1_name)(self.data)
                 self.assertRaises(TypeError, getattr(cipher, method2_name),
-                                  self.data_128)
+                                  self.data)
 
     def test_invalid_encrypt_or_update_after_digest(self):
         for method_name in "encrypt", "update":
             cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-            cipher.encrypt(self.data_128)
+            cipher.encrypt(self.data)
             cipher.digest()
             self.assertRaises(TypeError, getattr(cipher, method_name),
-                              self.data_128)
+                              self.data)
 
             cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-            cipher.encrypt_and_digest(self.data_128)
+            cipher.encrypt_and_digest(self.data)
 
     def test_invalid_decrypt_or_update_after_verify(self):
         cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
-        ct = cipher.encrypt(self.data_128)
+        ct = cipher.encrypt(self.data)
         mac = cipher.digest()
 
         for method_name in "decrypt", "update":
@@ -616,12 +650,12 @@ class CcmFSMTests(unittest.TestCase):
             cipher.decrypt(ct)
             cipher.verify(mac)
             self.assertRaises(TypeError, getattr(cipher, method_name),
-                              self.data_128)
+                              self.data)
 
             cipher = AES.new(self.key_128, AES.MODE_CCM, nonce=self.nonce_96)
             cipher.decrypt_and_verify(ct, mac)
             self.assertRaises(TypeError, getattr(cipher, method_name),
-                              self.data_128)
+                              self.data)
 
 
 class TestVectors(unittest.TestCase):
@@ -836,27 +870,14 @@ class TestVectorsWycheproof(unittest.TestCase):
         self._id = "None"
 
     def setUp(self):
-        comps = "Crypto.SelfTest.Cipher.test_vectors.wycheproof".split(".")
-        with open(pycryptodome_filename(comps, "aes_ccm_test.json"), "rt") as file_in:
-            tv_tree = json.load(file_in)
 
-        class TestVector(object):
-            pass
-        self.tv = []
+        def filter_tag(group):
+            return group['tagSize'] // 8
 
-        for group in tv_tree['testGroups']:
-            tag_size = group['tagSize'] // 8
-            for test in group['tests']:
-                tv = TestVector()
-                tv.tag_size = tag_size
-
-                tv.id = test['tcId']
-                tv.comment = test['comment']
-                for attr in 'key', 'iv', 'aad', 'msg', 'ct', 'tag':
-                    setattr(tv, attr, unhexlify(test[attr]))
-                tv.valid = test['result'] != "invalid"
-                tv.warning = test['result'] == "acceptable"
-                self.tv.append(tv)
+        self.tv = load_test_vectors_wycheproof(("Cipher", "wycheproof"),
+                                               "aes_ccm_test.json",
+                                               "Wycheproof AES CCM",
+                                               group_tag={'tag_size': filter_tag})
 
     def shortDescription(self):
         return self._id
@@ -871,7 +892,7 @@ class TestVectorsWycheproof(unittest.TestCase):
 
         try:
             cipher = AES.new(tv.key, AES.MODE_CCM, tv.iv, mac_len=tv.tag_size,
-                    **self._extra_params)
+                                **self._extra_params)
         except ValueError as e:
             if len(tv.iv) not in range(7, 13 + 1, 2) and "Length of parameter 'nonce'" in str(e):
                 assert not tv.valid
@@ -893,7 +914,7 @@ class TestVectorsWycheproof(unittest.TestCase):
 
         try:
             cipher = AES.new(tv.key, AES.MODE_CCM, tv.iv, mac_len=tv.tag_size,
-                    **self._extra_params)
+                                **self._extra_params)
         except ValueError as e:
             if len(tv.iv) not in range(7, 13 + 1, 2) and "Length of parameter 'nonce'" in str(e):
                 assert not tv.valid
@@ -918,7 +939,7 @@ class TestVectorsWycheproof(unittest.TestCase):
         if len(tv.iv) not in range(7, 13 + 1, 2) or len(tv.ct) == 0:
             return
         cipher = AES.new(tv.key, AES.MODE_CCM, tv.iv, mac_len=tv.tag_size,
-                **self._extra_params)
+                            **self._extra_params)
         cipher.update(tv.aad)
         ct_corrupt = strxor(tv.ct, b"\x00" * (len(tv.ct) - 1) + b"\x01")
         self.assertRaises(ValueError, cipher.decrypt_and_verify, ct_corrupt, tv.tag)
@@ -938,11 +959,12 @@ def get_tests(config={}):
     tests += list_test_cases(CcmTests)
     tests += list_test_cases(CcmFSMTests)
     tests += [TestVectors()]
-    tests += [ TestVectorsWycheproof(wycheproof_warnings) ]
- 
+    tests += [TestVectorsWycheproof(wycheproof_warnings)]
+
     return tests
 
 
 if __name__ == '__main__':
-    suite = lambda: unittest.TestSuite(get_tests())
+    def suite():
+        unittest.TestSuite(get_tests())
     unittest.main(defaultTest='suite')
